@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2007 daniel g. siegel <dgsiegel@gmail.com>
- * Copyright (C) 2007 Jaap Haitsma <jaap@haitsma.org>
+ * Copyright (C) 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
+ * Copyright (C) 2007,2008 Jaap Haitsma <jaap@haitsma.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -183,12 +183,13 @@ cheese_cairo_draw_card (cairo_t *cr, const GstEffect *card, gboolean highlight)
       CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 
   cairo_set_font_size (cr, 0.09);
-  cairo_text_extents (cr, card->name, &extents);
+  gchar *name = gettext(card->name);
+  cairo_text_extents (cr, name, &extents);
   x = 0.5 - (extents.width / 2 + extents.x_bearing);
   y = 0.92 - (extents.height / 2 + extents.y_bearing);
 
   cairo_move_to (cr, x, y);
-  cairo_show_text (cr, card->name);
+  cairo_show_text (cr, name);
 
   if (highlight)
   {
